module.exports = defineTest({
	description: 'renders hoisted variables in dead branches'
});
